/* -------------------------------------------------------------- */
/* 1.2: HISTOGRAM OF MONTHS BETWEEN BL, INTERVENTION AND FU    	  */
/* Also table of months, and chart between months & satisfaction  */
/* AUTHOR: Meritxell Martínez                                     */
/* LAST UPDATE: June2023	                                      */
/*                                                                */
/* -------------------------------------------------------------- */

clear
set more off 
version 12

/* -------------------------------------------------------------- */
////// LOG
/* -------------------------------------------------------------- */

local today = c(current_date)
local today = subinstr("`today'", " ", "", .)
cap log close
log using "$logs/hist_interv_months_`today'", replace

/* -------------------------------------------------------------- */
////// LOAD CLEAN DATA
/* -------------------------------------------------------------- */

use "$data/endline_clean.dta", clear

encode province, gen(prov)

gen endline=1

drop province

ren prov province

/* -------------------------------------------------------------- */
////// APPEND FU CLEAN DATA
/* -------------------------------------------------------------- */

preserve

	use "$data/fu_clean.dta", clear

	replace province=1 if province==3
	replace province=2 if province==4
	replace province=3 if province==29
	replace province=4 if province==21
	replace province=5 if province==25
	replace province=6 if province==32

	tempfile fu
	save `fu'

restore

append using `fu'


// Gen categorical variable of time passed

gen dif_interv_bl_cat=1 if dif_interv_bl<=2
replace dif_interv_bl_cat=2 if dif_interv_bl>2 & dif_interv_bl<=6
replace dif_interv_bl_cat=3 if dif_interv_bl>6 & dif_interv_bl<=12
replace dif_interv_bl_cat=4 if dif_interv_bl>12 & dif_interv_bl!=.

gen dif_interv_fu_cat=1 if dif_interv_fu<=2
replace dif_interv_fu_cat=2 if dif_interv_fu>2 & dif_interv_fu<=6
replace dif_interv_fu_cat=3 if dif_interv_fu>6 & dif_interv_fu<=9
replace dif_interv_fu_cat=4 if (dif_interv_fu>9 & dif_interv_fu<=12)|dif_interv_end<=12
replace dif_interv_fu_cat=5 if (dif_interv_fu>12 & dif_interv_fu<=15)|(dif_interv_end>12 & dif_interv_end<=15)
replace dif_interv_fu_cat=6 if (dif_interv_fu>15 & dif_interv_fu<=18)|(dif_interv_end>15 & dif_interv_end<=18)
replace dif_interv_fu_cat=7 if (dif_interv_fu>18 & dif_interv_fu!=.)|(dif_interv_end>18 & dif_interv_end<=24)
replace dif_interv_fu_cat=8 if (dif_interv_end>24 & dif_interv_end!=.)

lab define dif_cat 1 "< 2 meses" 2 "2-6 meses" 3 "6-12 meses" 4 "Más de 12 meses"
lab define dif_cat2 1 "< 2 meses" 2 "2-6 meses" 3 "6-9 meses" 4 "9-12 meses" 5 "12-15 meses" 6 "15-18 meses" 7 "18ms-2 años" 8 "+2 años"


lab val dif_interv_bl_cat dif_cat
lab val dif_interv_fu_cat dif_cat2

	lab var dif_interv_bl_cat "Tiempo transcurrido de linea de base a intervencion"
	lab var dif_interv_fu_cat "Tiempo transcurrido de intervencion a entrevista"
	
// Graph Two Way SCATTER PLOT of time to intervention against time to FU and time to Endline

gen dif_view_both=dif_interv_fu_all

replace dif_view_both=dif_interv_end_all if endline==1

lab var dif_view_both "Time for each HH"

preserve

	drop if rejection3==1
	
	bys dif_view_both dif_interv_bl_all d_treat: gen obs=_N
	
		graph twoway (scatter dif_view_both dif_interv_bl_all [fweight=obs] if d_treat==1, msymbol(circle_hollow)) ///
		(scatter dif_view_both dif_interv_bl_all [fweight=obs] if d_treat==0, msymbol(circle_hollow)), ///
	   legend(order(1 "Targeted Households" 2 "Untargeted Households")) ytitle("{&Delta}{sub:S} (months)", size(medium)) xtitle("{&Delta}{sub:T} (months)", size(medium))
		
	graph export "$figures/months_interv_together2.png", replace width(2000)

	
restore	
		
	
log close

/* -------------------------------------------------------------- */
////// THE END
/* -------------------------------------------------------------- */
