/* -------------------------------------------------------------- */
/* DELAY: NON LINEAR RESULTS - CHILDREN SPEC				  	  */
/* AUTHOR: Xavier Gine, Meritxell Martinez and Virginia Melo      */
/* LAST UPDATE: June2023	                                      */
/*                                                                */
/* -------------------------------------------------------------- */

use "$data/panel_complete.dta", clear

//encode regional, gen(region_code)
ren bl_hhmember_kid_10 d_kid
//keep if bl_hhmember_kid_10==1 // This is 37% of the observations


/* Make globals */ 
global fixed region_code

global panelNL satisf_d_house satisf_d_life

rename dif_interv_bl_all DeltaT 
rename dif_interv_intview DeltaS 
rename time_interv_tr DeltaT_tr 
rename time_intview_tr DeltaS_tr


/*
gen cDeltaT = 1.5 if DeltaT<3
replace cDeltaT = 3 if DeltaT>=3 & DeltaT < 7
replace cDeltaT = 8 if DeltaT >=7 & DeltaT < 10
replace cDeltaT = 17 if DeltaT >=10

gen cDeltaS = 3 if DeltaS<7
replace cDeltaS = 9 if DeltaS>=7 & DeltaS < 13
replace cDeltaS = 13 if DeltaS >=13 & DeltaS < 20
replace cDeltaS = 20 if DeltaS >=20



rename delta_t_cat cDeltaT 
rename delta_s_cat cDeltaS 
rename delta_t_cat_treat cDeltaT_tr 
rename delta_s_cat_treat cDeltaS_tr
*/

gen dDeltaS = (DeltaS>16)
gen dDeltaT = (DeltaT>5)

gen dDeltaT_tr = dDeltaT*d_treat
gen dDeltaS_tr = dDeltaS*d_treat

global treats DeltaT DeltaS d_treat DeltaT_tr DeltaS_tr

global controls bl_fullypaid bl_satisf_d_house bl_satisf_d_floor bl_satisf_d_wall bl_satisf_d_roof phone_survey no_satisf_wall no_satisf_roof


qui sum mortal_rate
local R = 0.05 + r(mean)

qui sum DeltaT, det
matrix DT = (r(p10), r(p25), r(p50), r(p75), r(p90))
local mDT = r(mean)

matrix dT = (0.026, 0.051)
matrix dD = (0.19, 0.029)

// Create dummies for fix effects

tab region_code, gen(region_code_)

// REGRESSIONS - Aixo son els loops de regressions. Veuras el resultat en pantalla, t'he comentat fora la part del codi que salva els resultats perque no tinguem problemes de estar salvant i sobreescribint sobre els meus results. Si vulguessis fer una regressio individual sense cridar les globals de outcomes, substitueix "foreach var of varlist  $takeup" per foreach var of varlist XXX on XXX es la variable que vols veure.

preserve

local action replace 
local dv = 1
foreach var of varlist   $panelNL {
*local lab : var label `var'
*areg `var' $treats bl_`var' $controls, a($fixed) vce(cluster newpolygid)


*reg `var' $treats, vce(cluster newpolygid)
*reg `var' $treats bl_`var' $controls, vce(cluster newpolygid)

*For Analog of Table 4 in Galiani et al 
*reg `var' d_treat bl_`var' $controls, vce(cluster newpolygid) /*Pooled Coefficient*/
*reg `var' d_treat dDeltaS_tr bl_`var' $controls, vce(cluster newpolygid)
*reg `var' d_treat dDeltaS_tr dDeltaT_tr bl_`var' $controls, vce(cluster newpolygid)


*reg `var' $dtreats $controls, vce(cluster newpolygid)
*reg `var' $dtreats1 bl_`var' $controls, vce(cluster newpolygid)

*bys cedula: gen id=_n if e(sample)
*count if e(sample) & id==1
*local n_ced: display %9.1f `r(N)'
*summ `var' if d_treat==0
// outreg2 using "$tables/main_out_panel_time_rest.xls", `action' excel nocons sideway keep($treats) bdec(3) sdec(3) slow(100)  ///
// addstat(Number of individuals, `n_ced', Mean dep. var for controls, `r(mean)', SD dep. var., `r(sd)') addtext(FEs, Province) label 
*drop id
/*
*For Analog of Table 4 in Galiani et al
nl (`var' = d_treat*({b0=0.5} + {b1=0.5}*(exp(-1*{b2=0.25}*DeltaS))) + {b5=1} + {b6=0} * bl_fullypaid + {b7=0} * bl_satisf_d_house + {b8=0} * bl_satisf_d_floor + {b9=0} * bl_satisf_d_wall + {b10=0} * bl_satisf_d_roof + {b11=0} * phone_survey), vce(cluster newpolygid)
nlcom _b[/b0]/`R' /*Permanent Gain*/
nlcom _b[/b1]/(`R'+_b[/b2])  /*Transitory Gain*/
nlcom _b[/b0]/`R' + _b[/b1]/(`R'+_b[/b2]) /*Total Gain*/
*/

*nl (`var' = d_treat*({b0=0.5} + {b1=0.5}*d_kid + ({b2=0.1} + {b3=0.1}*d_kid)*(exp(-1*{b4=0.1}*DeltaS)) + ({b5=0.5} + {b6=0.5}*d_kid)*(exp(-1*{b7=0.1}*DeltaT)-1)) + {b8=1} + {b9=0} * bl_fullypaid + {b10=0} * bl_satisf_d_house + {b11=0} * bl_satisf_d_floor + {b12=0} * bl_satisf_d_wall + {b13=0} * bl_satisf_d_roof + {b14=0} * phone_survey), vce(cluster newpolygid) iter(1000)

nl (`var' = d_treat*({b0=0.5} + {b1=0.5}*d_kid + ({b2=0.1} + {b3=0.1}*d_kid)*(exp(-1*dT[1,`dv']*DeltaS)) + ({b5=0.5} + {b6=0.5}*d_kid)*(exp(-1*dD[1,`dv']*DeltaT)-1)) + {b8=1} + {b9=0} * bl_fullypaid + {b10=0} * bl_satisf_d_house + {b11=0} * bl_satisf_d_floor + {b12=0} * bl_satisf_d_wall + {b13=0} * bl_satisf_d_roof + {b14=0} * phone_survey + {b15=0} * d_kid), vce(cluster newpolygid) iter(1000)

display "TABLE A10 PARAMETERS ESTIMATES BY PRESENCE OF CHILDREN"
nlcom _b[/b0] + _b[/b1] // Old beta_0, beta_P
display "Beta P above for Child"
nlcom _b[/b1] // beta_P: Dif Child vs No Child
display "Beta P: Dif Child vs No Child (always extract the p-value from the tests in these Dif lines)"
nlcom _b[/b0]
display "Beta P: No child"
nlcom _b[/b2] + _b[/b3] // Old beta_1, beta_T
display "Beta T above for Child"	
nlcom _b[/b3] // beta_T: Dif Child vs No Child
display "Beta T Dif Child vs No Child"
nlcom _b[/b2] // Old beta_1, beta_T
display "Beta T No child"	

*nlcom _b[/b4] // delta_T, just to have it in order
nlcom _b[/b5] + _b[/b6] // Old beta_3, beta_D
display "Beta D above for child"	
nlcom _b[/b6] // beta_D: Dif Child vs No Child
display "Beta D Dif Child vs No Child"
nlcom _b[/b5] // Old beta_3, beta_D
display "Beta D No child"	

*nlcom _b[/b7] // delta_D, just to have it in order

display "GAINS AND LOSSES - CHILDREN"

*For Analog of Table 4 in Galiani et al, CHILDREN
nlcom (_b[/b0]+_b[/b1])/`R' /*Permanent Gain */
display "Children Permanent Gain above"
nlcom (_b[/b1])/`R' /*Permanent Gain: Dif Child vs No Child */
display "Perm gain Dif Child vs No Child"

*nlcom (_b[/b2] + _b[/b3])*exp(-1*`R'*`mDT')/(`R'+_b[/b4]) + (_b[/b2] + _b[/b3])*(1-exp(-1*`R'*`mDT'))/`R' /*Transitory Gain*/

nlcom (_b[/b2] + _b[/b3])*exp(-1*`R'*`mDT')/(`R'+ dT[1,`dv']) + (_b[/b2] + _b[/b3])*(1-exp(-1*`R'*`mDT'))/`R' /*Transitory Gain*/
display "Children Transitory Gain above"
nlcom (_b[/b3])*exp(-1*`R'*`mDT')/(`R'+ dT[1,`dv']) + (_b[/b3])*(1-exp(-1*`R'*`mDT'))/`R' /*Transitory Gain: Dif Child vs Bo Child*/
display "Transitory Gain Dif Child vs No Child"

*nlcom (_b[/b5] + _b[/b6])*(_b[/b7]/(_b[/b7])+`R')*(1-exp(-1*(_b[/b7]+`R')*`mDT')) /*Delay Loss*/
nlcom (_b[/b5] + _b[/b6])*(dD[1,`dv']/(dD[1,`dv'])+`R')*(1-exp(-1*(dD[1,`dv']+`R')*`mDT')) /*Delay Loss*/
display "Children Delay Loss above"
nlcom (_b[/b6])*(dD[1,`dv']/(dD[1,`dv'])+`R')*(1-exp(-1*(dD[1,`dv']+`R')*`mDT')) /*Delay Loss: Dif Child vs Bo Child*/
display "Delay Loss Dif Child and No Child"

*nlcom (_b[/b0]+_b[/b1])/`R' + (_b[/b2] + _b[/b3])*exp(-1*`R'*`mDT')/(`R'+_b[/b4]) + (_b[/b2] + _b[/b3])*(1-exp(-1*`R'*`mDT'))/`R' - (_b[/b5] + _b[/b6])*(_b[/b7]/(_b[/b7])+`R')*(1-exp(-1*(_b[/b7]+`R')*`mDT')) /*Total Gain*/

nlcom (_b[/b0]+_b[/b1])/`R' + (_b[/b2] + _b[/b3])*exp(-1*`R'*`mDT')/(`R'+dT[1,`dv']) + (_b[/b2] + _b[/b3])*(1-exp(-1*`R'*`mDT'))/`R' - (_b[/b5] + _b[/b6])*(dD[1,`dv']/(dD[1,`dv'])+`R')*(1-exp(-1*(dD[1,`dv']+`R')*`mDT')) /*Total Gain*/
display "Children Total Gain above"
nlcom (_b[/b1])/`R' + (_b[/b3])*exp(-1*`R'*`mDT')/(`R'+dT[1,`dv']) + (_b[/b3])*(1-exp(-1*`R'*`mDT'))/`R' - (_b[/b6])*(dD[1,`dv']/(dD[1,`dv'])+`R')*(1-exp(-1*(dD[1,`dv']+`R')*`mDT')) /*Total Gain*/
display "Total Gain Dif Child vs No Child"

display "GAINS AND LOSSES - NO CHILDREN"

*For Analog of Table 4 in Galiani et al, NO CHILDREN
nlcom _b[/b0]/`R' /*Permanent Gain */
display "No Children Permanent Gain above"
*nlcom _b[/b2]*exp(-1*`R'*`mDT')/(`R'+_b[/b4]) + _b[/b2]*(1-exp(-1*`R'*`mDT'))/`R' /*Transitory Gain*/
nlcom _b[/b2]*exp(-1*`R'*`mDT')/(`R'+ dT[1,`dv']) + _b[/b2]*(1-exp(-1*`R'*`mDT'))/`R' /*Transitory Gain*/
display "No Children Transitory Gain above"
*nlcom _b[/b5]*(_b[/b7]/(_b[/b7]+`R'))*(1-exp(-1*(_b[/b7]+`R')*`mDT')) /*Delay Loss*/
nlcom _b[/b5]*(dD[1,`dv']/(dD[1,`dv']+`R'))*(1-exp(-1*(dD[1,`dv']+`R')*`mDT')) /*Delay Loss*/
display "No Children Delay Loss above"

*nlcom _b[/b0]/`R'+ _b[/b2]*exp(-1*`R'*`mDT')/(`R'+_b[/b4]) + _b[/b2]*(1-exp(-1*`R'*`mDT'))/`R' - _b[/b5]*(_b[/b7]/(_b[/b7]+`R'))*(1-exp(-1*(_b[/b7]+`R')*`mDT')) /*Total Gain*/

nlcom _b[/b0]/`R'+ _b[/b2]*exp(-1*`R'*`mDT')/(`R'+ dT[1,`dv']) + _b[/b2]*(1-exp(-1*`R'*`mDT'))/`R' - _b[/b5]*(dD[1,`dv']/(dD[1,`dv']+`R'))*(1-exp(-1*(dD[1,`dv']+`R')*`mDT')) /*Total Gain*/
display "No Children Total Gain above"

/*display "NEW 0, P10, P50... tables - CHILDREN"
*For new table where D_T takes values 0, p10, p25, p50, p75 and p90, CHILDREN
nlcom (_b[/b2] + _b[/b3])/(`R'+_b[/b4]) 
forvalues i=1/5 {
	nlcom (_b[/b2] + _b[/b3])*exp(-1*`R'*DT[1,`i'])/(`R'+_b[/b4]) + (_b[/b2] + _b[/b3])*(1-exp(-1*`R'*DT[1,`i']))/`R' /*Transitory Gain*/
	nlcom (_b[/b5] + _b[/b6])*(_b[/b7]/(_b[/b7]+`R'))*(1-exp(-1*(_b[/b7]+`R')*DT[1,`i'])) /*Delay Loss*/
}
*/

/*display "NEW 0, P10, P50... tables - NO CHILDREN"

*For new table where D_T takes values 0, p10, p25, p50, p75 and p90, NO CHILDREN
nlcom _b[/b2]/(`R'+_b[/b4]) 
forvalues i=1/5 {
	nlcom _b[/b2]*exp(-1*`R'*DT[1,`i'])/(`R'+_b[/b4]) + _b[/b2]*(1-exp(-1*`R'*DT[1,`i']))/`R' /*Transitory Gain*/
	nlcom _b[/b5]*(_b[/b7]/(_b[/b7]+`R'))*(1-exp(-1*(_b[/b7]+`R')*DT[1,`i'])) /*Delay Loss*/
}
*/
*nl (`var' = d_treat*({b0=0.5} + {b1=0.5}*(exp(-1*{b2=0.1}*cDeltaS)) + {b3=0.5}*(exp(-1*{b4=0.1}*cDeltaT)-1)) + {b5=1} + {b6=0} * bl_fullypaid + {b7=0} * bl_satisf_d_house + {b8=0} * bl_satisf_d_floor + {b9=0} * bl_satisf_d_wall + {b10=0} * bl_satisf_d_roof + {b11=0} * phone_survey), vce(cluster newpolygid) iter(1000)
/*
nl (`var' = d_treat*({b0=0.5} + {b1=1}*(1-dDeltaS1) + dDeltaT1*{b3=1}) + {b5=1} + {b6=0} * bl_fullypaid + {b7=0} * bl_satisf_d_house + {b8=0} * bl_satisf_d_floor + {b9=0} * bl_satisf_d_wall + {b10=0} * bl_satisf_d_roof + {b11=0} * phone_survey + {b12=0} * no_satisf_wall + {b13=0} * no_satisf_roof + {b14=0} * no_satisf_roof + {b15=0} * region_code_1 + {b16=0} * region_code_2 + {b17=0} * region_code_3 + {b18=0} * region_code_4 + {b19=0} * region_code_5 /*+ {b15=0} * mun_code_1 + {b16=0} * mun_code_2 + {b17=0} * mun_code_3 + {b18=0} * mun_code_4 + {b19=0} * mun_code_5 + {b20=0} * mun_code_6 + {b21=0} * mun_code_7 + {b22=0} * mun_code_8 + {b23=0} * mun_code_9 + {b24=0} * mun_code_10 + {b25=0} * mun_code_11 + {b26=0} * mun_code_12 + {b27=0} * mun_code_13 + {b28=0} * mun_code_14 + {b29=0} * mun_code_15 + {b30=0} * mun_code_17 + {b31=0} * mun_code_18 + {b32=0} * mun_code_19 + {b33=0} * mun_code_20 + {b34=0} * mun_code_21 + {b35=0} * mun_code_22 + {b36=0} * mun_code_23 + {b37=0} * mun_code_24 + {b38=0} * mun_code_25 + {b39=0} * mun_code_26 + {b40=0} * mun_code_27*/), vce(cluster newpolygid)


nl (`var' = d_treat*({b0=0.5} + {b2=0.1}*(exp(-1*dT[1,`dv']*DeltaS)) + ({b5=0.5} + {b6=0.5}*d_kid)*(exp(-1*dD[1,`dv']*DeltaT)-1)) + {b8=1} + {b9=0} * bl_fullypaid + {b10=0} * bl_satisf_d_house + {b11=0} * bl_satisf_d_floor + {b12=0} * bl_satisf_d_wall + {b13=0} * bl_satisf_d_roof + {b14=0} * phone_survey + {b15=0} * d_kid), vce(cluster newpolygid) iter(1000)

display "CHILD betas in NL PARS table, 1 for every couple of coefficients (no needed for beta_4 and beta_7, they are not split)"
nlcom _b[/b0] // Old beta_0, beta_P
nlcom _b[/b2] // Old beta_1, beta_T

nlcom _b[/b5] + _b[/b6] // Old beta_3, beta_D
nlcom _b[/b6] // beta_D: Dif Child vs No Child
*nlcom _b[/b7] // delta_D, just to have it in order

display "GAINS AND LOSSES - CHILDREN"


nlcom (_b[/b5] + _b[/b6])*(dD[1,`dv']/(dD[1,`dv'])+`R')*(1-exp(-1*(dD[1,`dv']+`R')*`mDT')) /*Delay Loss*/

nlcom (_b[/b6])*(dD[1,`dv']/(dD[1,`dv'])+`R')*(1-exp(-1*(dD[1,`dv']+`R')*`mDT')) /*Delay Loss: Dif Child vs Bo Child*/

nlcom (_b[/b0])/`R' + (_b[/b2])*exp(-1*`R'*`mDT')/(`R'+dT[1,`dv']) + (_b[/b2])*(1-exp(-1*`R'*`mDT'))/`R' - (_b[/b5] + _b[/b6])*(dD[1,`dv']/(dD[1,`dv'])+`R')*(1-exp(-1*(dD[1,`dv']+`R')*`mDT')) /*Total Gain*/


display "GAINS AND LOSSES - NO CHILDREN"

*For Analog of Table 4 in Galiani et al, NO CHILDREN
nlcom _b[/b0]/`R' /*Permanent Gain */
*nlcom _b[/b2]*exp(-1*`R'*`mDT')/(`R'+_b[/b4]) + _b[/b2]*(1-exp(-1*`R'*`mDT'))/`R' /*Transitory Gain*/
nlcom _b[/b2]*exp(-1*`R'*`mDT')/(`R'+ dT[1,`dv']) + _b[/b2]*(1-exp(-1*`R'*`mDT'))/`R' /*Transitory Gain*/
*nlcom _b[/b5]*(_b[/b7]/(_b[/b7]+`R'))*(1-exp(-1*(_b[/b7]+`R')*`mDT')) /*Delay Loss*/
nlcom _b[/b5]*(dD[1,`dv']/(dD[1,`dv']+`R'))*(1-exp(-1*(dD[1,`dv']+`R')*`mDT')) /*Delay Loss*/

nlcom _b[/b0]/`R'+ _b[/b2]*exp(-1*`R'*`mDT')/(`R'+ dT[1,`dv']) + _b[/b2]*(1-exp(-1*`R'*`mDT'))/`R' - _b[/b5]*(dD[1,`dv']/(dD[1,`dv']+`R'))*(1-exp(-1*(dD[1,`dv']+`R')*`mDT')) /*Total Gain*/



*/
local dv = `dv' + 1
}
local action replace
restore
