/* -------------------------------------------------------------- */
/* DELAY: LINEAR OUTCOMES                                         */
/*                                                                */
/* AUTHOR: Xavier Gine, Meritxell Martinez and Virginia Melo      */
/* LAST UPDATE: MAR 2023                                          */
/*                                                                */
/* -------------------------------------------------------------- */

clear
set more off 
version 15

/* -------------------------------------------------------------- */
////// LOG
/* -------------------------------------------------------------- */

local today = c(current_date)
local today = subinstr("`today'", " ", "", .)
cap log close
log using "$logs/main_out_time_panel_`today'", replace




use "$data/panel_complete.dta", clear



/* -------------------------------------------------------------- */
////// VARIABLES FOR MAIN OUTCOMES
/* -------------------------------------------------------------- */

/* Make globals */

global takeup 		hh_executed ///
					hh_executed_any ///
					s_dirtbedroom ///
					hh_painted_walls ///
					hh_floor
					
										
global takeup_alt 	hh_offered ///
					hh_executed ///
					hh_painted_walls ///
					hh_floor					
				  
global panelB 	    satisf_d_house ///
					satisf_d_floor ///
					satisf_d_color
					
	
global panelC		satisf_d_wall ///
					satisf_d_roof
					
					
global panelD		satisf_d_life ///
					trust ///
					marketrent
					
global panelB_alt 	satisf_d_house ///
					satisf_d_prosoli ///
					satisf_d_floor ///
					satisf_d_wall satisf_wall1 satisf_wall2 satisf_wall3 satisf_wall4 satisf_wall5 ///
					satisf_d_color satisf_color1 satisf_color2 satisf_color3 satisf_color4 satisf_color5 ///
					satisf_d_roof ///
					satisf_d_leak ///
					satisf_d_life ///
					satisf_d_general ///
					plan_move
								
	
global treats		dif_interv_bl_all dif_interv_intview  d_treat time_interv_tr time_intview_tr 

global treats_dummy		dif_interv_bl_all_5m_inv dif_interv_fu_all_16m_inv  d_treat time_interv_tr2 time_intview_tr2 

global treats_only		dif_interv_bl_all dif_interv_intview 

global treats_probit		dif_interv_bl_all dif_interv_intview  d_treat c.time_interv_tr c.time_intview_tr 

global controls		bl_fullypaid bl_satisf_d_house bl_satisf_d_floor bl_satisf_d_wall bl_satisf_d_roof phone_survey no_satisf_wall no_satisf_roof

global fixed mun_code


/* Controls */

// No controls for now



/* -------------------------------------------------------------- */
////// REGRESSIONS with EXCEL OUTPUT
/* -------------------------------------------------------------- */

		/* ALL ARE less contaminated polygons (rejection treated rate less or equal than 50%, as given by variable rejection3) */

preserve

	local action replace

	//drop if rejection3==1 No longer needed we drop them from the general panel above
	

	foreach var of varlist  $takeup {
		
			local lab : var label `var'
		
				areg `var' $treats, a($fixed) vce(cluster newpolygid)
			
				bys cedula: gen id=_n if e(sample)
				count if e(sample) & id==1
				local n_ced: display %9.1f `r(N)'
				cap summ `var' if d_treat==0
				outreg2 using "$tables/main_out_panel_time_rest.xls", `action' excel nocons sideway keep($treats) bdec(3) sdec(3) slow(100)  ///
				addstat(Number of individuals, `n_ced', Mean dep. var for controls, `r(mean)', SD dep. var., `r(sd)') addtext(FEs, Province) label 
				
				drop id
				
				
		local action append
}

		foreach var of varlist   $panelB $panelC $panelD {
		
			local lab : var label `var'
		
				areg `var' $treats bl_`var' $controls, a($fixed) vce(cluster newpolygid)
				
				bys cedula: gen id=_n if e(sample)
				count if e(sample) & id==1
				local n_ced: display %9.1f `r(N)'
				summ `var' if d_treat==0
				
				outreg2 using "$tables/main_out_panel_time_rest.xls", `action' excel nocons sideway keep($treats) bdec(3) sdec(3) slow(100)  ///
				addstat(Number of individuals, `n_ced', Mean dep. var for controls, `r(mean)', SD dep. var., `r(sd)') addtext(FEs, Province) label 
				
				drop id
			
			
		}
		
	
						
restore

		/* HOUSEHOLDS WITH CHILDREN */

preserve

	local action replace

	//drop if rejection3==1 No longer needed we drop them from the general panel above
	
	keep if bl_hhmember_kid_10==1 // This is 37% of the observations

	foreach var of varlist  $takeup {
		
			local lab : var label `var'
		
				areg `var' $treats, a($fixed) vce(cluster newpolygid)
			
				bys cedula: gen id=_n if e(sample)
				count if e(sample) & id==1
				local n_ced: display %9.1f `r(N)'
				cap summ `var' if d_treat==0
				outreg2 using "$tables/main_out_panel_time_child.xls", `action' excel nocons sideway keep($treats) bdec(3) sdec(3) slow(100)  ///
				addstat(Number of individuals, `n_ced', Mean dep. var for controls, `r(mean)', SD dep. var., `r(sd)') addtext(FEs, Province) label 
				
				drop id
				
				
		local action append
}

		foreach var of varlist   $panelB $panelC $panelD {
		
			local lab : var label `var'
		
				areg `var' $treats bl_`var' $controls, a($fixed) vce(cluster newpolygid)
				
				bys cedula: gen id=_n if e(sample)
				count if e(sample) & id==1
				local n_ced: display %9.1f `r(N)'
				summ `var' if d_treat==0
				
				outreg2 using "$tables/main_out_panel_time_child.xls", `action' excel nocons sideway keep($treats) bdec(3) sdec(3) slow(100)  ///
				addstat(Number of individuals, `n_ced', Mean dep. var for controls, `r(mean)', SD dep. var., `r(sd)') addtext(FEs, Province) label 
				
				drop id
			
			
		}
		
	
						
restore

	/* DUMMY REGRESSIONS WITH LESS OR MORE THAN MEDIAN */

preserve

	local action replace

	//drop if rejection3==1 No longer needed we drop them from the general panel above
	

	foreach var of varlist  $takeup {
		
			local lab : var label `var'
		
				areg `var' $treats_dummy, a($fixed) vce(cluster newpolygid)
			
				bys cedula: gen id=_n if e(sample)
				count if e(sample) & id==1
				local n_ced: display %9.1f `r(N)'
				cap summ `var' if d_treat==0
				outreg2 using "$tables/main_out_panel_time_rest_dum.xls", `action' excel nocons sideway keep($treats_dummy) bdec(3) sdec(3) slow(100)  ///
				addstat(Number of individuals, `n_ced', Mean dep. var for controls, `r(mean)', SD dep. var., `r(sd)') addtext(FEs, Province) label 
				
				drop id
				
				
		local action append
}

		foreach var of varlist   $panelB $panelC $panelD {
		
			local lab : var label `var'
		
				areg `var' $treats_dummy bl_`var' $controls, a($fixed) vce(cluster newpolygid)
				
				bys cedula: gen id=_n if e(sample)
				count if e(sample) & id==1
				local n_ced: display %9.1f `r(N)'
				summ `var' if d_treat==0
				
				outreg2 using "$tables/main_out_panel_time_rest_dum.xls", `action' excel nocons sideway keep($treats_dummy) bdec(3) sdec(3) slow(100)  ///
				addstat(Number of individuals, `n_ced', Mean dep. var for controls, `r(mean)', SD dep. var., `r(sd)') addtext(FEs, Province) label 
				
				drop id
			
			
		}
		
	
						
restore



/* ONLY CONTROLS */

// Variable of interaction of time x control is in targeted cluster

replace d_contamincontrol=0 if d_contamincontrol==.
replace d_contamincontrol=1 if treatgroup==1

gen time_intview_tr_clus=dif_interv_intview*d_contamincontrol
gen time_interv_tr_clus=dif_interv_bl_all*d_contamincontrol

global untargeted dif_interv_bl_all dif_interv_intview  d_contamincontrol time_interv_tr_clus time_intview_tr_clus 

preserve

	keep if d_treat==0 // ONLY CONTROLS

	local action replace
	

	foreach var of varlist  $takeup {
		
			local lab : var label `var'
		
				areg `var' $untargeted, a($fixed) vce(cluster newpolygid)
				bys cedula: gen id=_n if e(sample)
				count if e(sample) & id==1
				local n_ced: display %9.1f `r(N)'
				cap summ `var' if d_contamincontrol==0
				outreg2 using "$tables/main_out_panel_time_rest_untar.xls", `action' excel nocons sideway keep($untargeted) bdec(3) sdec(3) slow(100)  ///
				addstat(Number of individuals, `n_ced', Mean dep. var for controls, `r(mean)', SD dep. var., `r(sd)') addtext(FEs, Province) label 
				drop id
				
		local action append
}


	
		foreach var of varlist   $panelB $panelC $panelD {
		
			local lab : var label `var'
		
				areg `var' $untargeted bl_`var' $controls, a($fixed) vce(cluster newpolygid)
				bys cedula: gen id=_n if e(sample)
				count if e(sample) & id==1
				local n_ced: display %9.1f `r(N)'
				summ `var' if d_contamincontrol==0
				outreg2 using "$tables/main_out_panel_time_rest_untar.xls", `action' excel nocons sideway keep($untargeted) bdec(3) sdec(3) slow(100)  ///
				addstat(Number of individuals, `n_ced', Mean dep. var for controls, `r(mean)', SD dep. var., `r(sd)') addtext(FEs, Province) label 
				drop id
				
		}
				
		
		
restore

/* SAME, but without fixed effects (so only main regressions, take up will be the same as in the main results) */

preserve

	local action replace
	
	foreach var of varlist  $takeup {
		
			local lab : var label `var'
		
				reg `var' $treats, vce(cluster newpolygid)
			
				bys cedula: gen id=_n if e(sample)
				count if e(sample) & id==1
				local n_ced: display %9.1f `r(N)'
				cap summ `var' if d_treat==0
				outreg2 using "$tables/main_out_panel_time_rest_nocon.xls", `action' excel nocons sideway keep($treats) bdec(3) sdec(3) slow(100)  ///
				addstat(Number of individuals, `n_ced', Mean dep. var for controls, `r(mean)', SD dep. var., `r(sd)') addtext(FEs, None) label 
				
				drop id
				
				
		local action append
}
	
	
		foreach var of varlist   $panelB $panelC $panelD {
		
			local lab : var label `var'
		
				reg `var' $treats bl_`var' $controls, vce(cluster newpolygid)
				bys cedula: gen id=_n if e(sample)
				count if e(sample) & id==1
				local n_ced: display %9.1f `r(N)'
				summ `var' if d_treat==0
				outreg2 using "$tables/main_out_panel_time_rest_nocon.xls", `action' excel nocons sideway keep($treats) bdec(3) sdec(3) slow(100)  ///
				addstat(Number of individuals, `n_ced', Mean dep. var for controls, `r(mean)', SD dep. var., `r(sd)') addtext(FEs, None) label 
				drop id
				
		local action append
				
		}
				
		
		
		
restore


/* ONLY BALANCED PANEL (BOTH FU AND ENDLINE) */

preserve

	bys cedula: egen balanced1=total(fu_data)
	bys cedula: egen balanced2=total(endline)
	
	tab balanced1 balanced2
	
	gen balanced=balanced1+balanced2
	
	keep if balanced==2 // these are the respondants that have both FU and endline. It's 622 HHs, 1,244 observations
	
	tab fu_data // perfect
	tab endline

	local action replace
	
	foreach var of varlist  $takeup {
		
			local lab : var label `var'
		
				areg `var' $treats, a($fixed) vce(cluster newpolygid)
			
				bys cedula: gen id=_n if e(sample)
				count if e(sample) & id==1
				local n_ced: display %9.1f `r(N)'
				cap summ `var' if d_treat==0
				outreg2 using "$tables/main_out_panel_time_rest_balanced.xls", `action' excel nocons sideway keep($treats) bdec(3) sdec(3) slow(100)  ///
				addstat(Number of individuals, `n_ced', Mean dep. var for controls, `r(mean)', SD dep. var., `r(sd)') addtext(FEs, None) label 
				
				drop id
				
				
		local action append
}
	
	
		foreach var of varlist   $panelB $panelC $panelD {
		
			local lab : var label `var'
		
				areg `var' $treats bl_`var' $controls, a($fixed) vce(cluster newpolygid)
				bys cedula: gen id=_n if e(sample)
				count if e(sample) & id==1
				local n_ced: display %9.1f `r(N)'
				summ `var' if d_treat==0
				outreg2 using "$tables/main_out_panel_time_rest_balanced.xls", `action' excel nocons sideway keep($treats) bdec(3) sdec(3) slow(100)  ///
				addstat(Number of individuals, `n_ced', Mean dep. var for controls, `r(mean)', SD dep. var., `r(sd)') addtext(FEs, None) label 
				drop id
				
		local action append
				
		}
				
		
		
restore



/* -------------------------------------------------------------- */
////// THE END
/* -------------------------------------------------------------- */
