/* -------------------------------------------------------------- */
/* PISO: orthogonality checks, with time to interv and FU 		  */
/*                                                                */
/* AUTHOR: Meritxell Martinez                                     */
/* LAST UPDATE: Jan2023											  */
/*                   											  */
/* -------------------------------------------------------------- */

clear
set more off 
version 12

/* -------------------------------------------------------------- */
////// LOG
/* -------------------------------------------------------------- */

local today = c(current_date)
local today = subinstr("`today'", " ", "", .)
cap log close
log using "$logs/orthochecks_new_`today'", replace



/* Load BL matched roster (has ALL households analyzed, by row) */
use "$data\baseline_panel.dta", clear



/* Make globals */
global panelA 		bl_hhsize bl_hhmember_head_female educ_level bl_satisf_d_house bl_satisf_d_floor bl_satisf_d_wall bl_satisf_d_roof ///
						bl_satisf_d_life icv_compact_siuben bl_hhmember_hours_head
					
				  
global panelB 	    bl_dirtfloor ///
					bl_nrooms ///
					bl_s_dirtbedroom ///
					bl_outsidewalls_woodzinc ///
					bl_fullypaid ///
					bl_marketrent ///
					bl_urgentimprov_notfloor
					
// T-test for distances (only needed for first balance, only available for control HHs)

preserve

	drop if d_treat==1
	
	ttest km_to_treat, by(d_contamincontrol)
	
restore
					

/* -------------------------------------------------------------- */
////// GENERAL BALANCE
/* -------------------------------------------------------------- */

/* FINAL RESTRICTED SAMPLE (n=1036) */

encode mun, gen(mun_code)

encode regional, gen(region_code)


preserve


	iebaltab $panelA $panelB, ///
								grpvar(treatg_final) ///
								rowvarlabels /*balmissreg(zero)*/ ///
								vce(cluster newpolygid) fixedeffect(mun_code)      ///
								nottest feqtest pftest fmissok starsnoadd ///
								format(%9.3f) notecombine ///
								save("$tables\general_ortho_new_A_B.xlsx") replace
								
restore		

/* -------------------------------------------------------------- */
////// CHILDREN BALANCE
/* -------------------------------------------------------------- */	

preserve


	iebaltab $panelA $panelB, ///
								grpvar(treat_child) ///
								rowvarlabels /*balmissreg(zero)*/ ///
								vce(cluster newpolygid) fixedeffect(mun_code)      ///
								nottest feqtest pftest fmissok starsnoadd ///
								format(%9.3f) notecombine ///
								save("$tables\children_ortho_gen.xlsx") replace
								
restore	

preserve


	iebaltab $panelA $panelB, ///
								grpvar(bl_hhmember_kid_10) ///
								rowvarlabels /*balmissreg(zero)*/ ///
								vce(cluster newpolygid) fixedeffect(mun_code)      ///
								ftest pttest pftest fmissok starsnoadd ///
								format(%9.3f) notecombine ///
								save("$tables\children_ortho_7.xlsx") replace
								
restore		

preserve

	keep if bl_hhmember_kid_10==0

	iebaltab $panelA $panelB, ///
								grpvar(d_treat) ///
								rowvarlabels /*balmissreg(zero)*/ ///
								vce(cluster newpolygid) fixedeffect(mun_code)      ///
								ftest pttest pftest fmissok starsnoadd ///
								format(%9.3f) notecombine ///
								save("$tables\children_ortho_nochild.xlsx") replace
								
restore		

preserve

	keep if bl_hhmember_kid_10==1

	iebaltab $panelA $panelB, ///
								grpvar(d_treat) ///
								rowvarlabels /*balmissreg(zero)*/ ///
								vce(cluster newpolygid) fixedeffect(mun_code)      ///
								ftest pttest pftest fmissok starsnoadd ///
								format(%9.3f) notecombine ///
								save("$tables\children_ortho_child.xlsx") replace
								
restore		

preserve


	iebaltab $panelA $panelB, ///
								grpvar(treat_child) grplabels(0 Control & Child @ 1 Target & Child @ 2 Control & No Child @ 3 Target & No Child ) ///
								rowvarlabels /*balmissreg(zero)*/ ///
								vce(cluster newpolygid) fixedeffect(mun_code)      ///
								nottest feqtest pftest fmissok starsnoadd ///
								format(%9.3f) notecombine ///
								save("$tables\children_ortho_new_7.xlsx") replace
								
restore					


/* -------------------------------------------------------------- */
////// DELTA T AND S BALANCES
/* -------------------------------------------------------------- */


preserve

	/* Column 7, delay to treatment */
	iebaltab $panelA $panelB, ///
								grpvar(dif_interv_bl_all_5m) grplabels(0 Long @ 1 Short) ///
								rowvarlabels balmissreg(zero) ///
								vce(cluster newpolygid) fixedeffect(mun_code) ///
								ftest pttest pftest fmissok starsnoadd ///
								format(%9.3f) notecombine ///
								save("$tables\OChecks_DT_7_A_B.xlsx") replace

												
restore


preserve

	/* Columns 7, delay to survey */
	iebaltab $panelA $panelB, ///
								grpvar(dif_interv_fu_all_16m) grplabels(0 Long @ 1 Short) ///
								rowvarlabels balmissreg(zero) ///
								vce(cluster newpolygid) fixedeffect(mun_code) ///
								ftest pttest pftest fmissok starsnoadd ///
								format(%9.3f) notecombine ///
								save("$tables\OChecks_DS_7_A_B.xlsx") replace

												
restore

preserve

/* Columns 1,2 and 5, Delta T */

	keep if dif_interv_bl_all_5m==1

	
	iebaltab $panelA $panelB, ///
								grpvar(d_treat) grplabels(0 Control @ 1 T) ///
								rowvarlabels balmissreg(zero) ///
								vce(cluster newpolygid) fixedeffect(mun_code) ///
								ftest pttest pftest fmissok starsnoadd ///
								format(%9.3f) notecombine ///
								save("$tables\OChecks_DT_1_2_A_B.xlsx") replace

												
restore

preserve

/* Columns 3,4 and 6, Delta T */

	keep if dif_interv_bl_all_5m==0

	/* Columns 1 to 3 */
	iebaltab $panelA $panelB, ///
								grpvar(d_treat) grplabels(0 Control @ 1 T) ///
								rowvarlabels balmissreg(zero) ///
								vce(cluster newpolygid) fixedeffect(mun_code) ///
								ftest pttest pftest fmissok starsnoadd ///
								format(%9.3f) notecombine ///
								save("$tables\OChecks_DT_3_4_A_B.xlsx") replace

								
	
restore

preserve

/* Columns 1,2 and 5, Delta S */

	keep if dif_interv_fu_all_16m==1

	iebaltab $panelA $panelB, ///
								grpvar(d_treat) grplabels(0 Control @ 1 T) ///
								rowvarlabels balmissreg(zero) ///
								vce(cluster newpolygid) fixedeffect(mun_code) ///
								ftest pttest pftest fmissok starsnoadd ///
								format(%9.3f) notecombine ///
								save("$tables\OChecks_DS_1_2_A_B_v2.xlsx") replace

												
	
restore

preserve

/* Columns 3,4 and 6, Delta S */

	keep if dif_interv_fu_all_16m==0

	iebaltab $panelA $panelB, ///
								grpvar(d_treat) grplabels(0 Control @ 1 T) ///
								rowvarlabels balmissreg(zero) ///
								vce(cluster newpolygid) fixedeffect(mun_code) ///
								ftest pttest pftest fmissok starsnoadd ///
								format(%9.3f) notecombine ///
								save("$tables\OChecks_DS_3_4_A_B_v2.xlsx") replace
												
	
restore
					
								
log close 

/* END */
